"""Configuration file for the Sphinx documentation builder.

This file only contains a selection of the most common options. For a full
list see the documentation:
https://www.sphinx-doc.org/en/master/usage/configuration.html
"""

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = "repod"
copyright = "2022, David Runge"
author = "David Runge"

# The full version, including alpha/beta/rc tags
release = "latest"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinxarg.ext",
    "sphinxcontrib.programoutput",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

manpages_url = "https://man.archlinux.org/man/{page}.{section}"

# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]
html_logo = "artwork/logo.png"
html_favicon = "artwork/logo.ico"

html_context = {
    "display_gitlab": True,
    "gitlab_host": "gitlab.archlinux.org",
    "gitlab_user": "archlinux",
    "gitlab_repo": "repod",
    "gitlab_version": "main",
    "conf_py_path": "/docs/",
}
# -- Options for manual page output ------------------------------------------

man_pages = [
    ("repod/man/repod_file", "repod-file", "", ["David Runge"], 1),
    ("repod/man/repod_conf", "repod.conf", "", ["David Runge"], 5),
]
man_show_urls = True
man_make_section_directory = True
